IRC protocol types — backed by the irc-proto crate.
This module re-exports the types from irc-proto that the rest of the
crate uses.
Structs
- Ctcp
Message - A parsed CTCP (Client-to-Client Protocol) message extracted from the
trailing parameter of a
PRIVMSGorNOTICE. - Message
- A data structure representing an IRC message according to the protocol specification. It
consists of a collection of IRCv3 tags, a prefix (describing the source of the message), and
the protocol command. If the command is unknown, it is treated as a special raw command that
consists of a collection of arguments and the special suffix argument. Otherwise, the command
is parsed into a more useful form as described in
Command.
Enums
- Command
- List of all client commands as defined in RFC 2812. This also includes commands from the capabilities extension. Additionally, this includes some common additional commands from popular IRCds.
- Prefix
- The Prefix indicates “the true origin of the message”, according to the server.
- Response
- List of all server responses as defined in RFC 2812 and Modern docs (henceforth referred to as Modern). All commands are documented with their expected form from the RFC, and any useful, additional information about the response code.
Traits
- Channel
Ext - An extension trait giving strings a function to check if they are a channel.